@@ -22,17 +22,17 @@
 #include "dialog_user.h"
 #include "dialog_users_list.h"
 #include "dialog_new_group.h"
-#include <glom/libglom/standard_table_prefs_fields.h>
-#include <glom/libglom/glade_utils.h>
+#include <libglom/standard_table_prefs_fields.h>
+#include <glom/glade_utils.h>
 #include <glom/glom_privs.h>
 //#include <libgnome/gnome-i18n.h>
-#include <bakery/App/App_Gtk.h> //For util_bold_message().
+#include <glom/utils_ui.h> //For bold_message()).
 #include <glibmm/i18n.h>
 
 namespace Glom
 {
 
-Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   m_treeview_groups(0),
   m_button_group_new(0),
@@ -41,8 +41,8 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
 {
   //set_default_size(600, -1);
 
-  refGlade->get_widget("treeview_groups", m_treeview_groups);
-  refGlade->get_widget("treeview_tables", m_treeview_tables);
+  builder->get_widget("treeview_groups", m_treeview_groups);
+  builder->get_widget("treeview_tables", m_treeview_tables);
 
   m_model_groups = Gtk::ListStore::create(m_model_columns_groups);
   m_model_tables = Gtk::ListStore::create(m_model_columns_tables);
@@ -92,13 +92,13 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
     refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_treeview_tables_selection_changed) );
   }
 
-  refGlade->get_widget("button_group_new", m_button_group_new);
+  builder->get_widget("button_group_new", m_button_group_new);
   m_button_group_new->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_button_group_new) );
 
-  refGlade->get_widget("button_group_delete", m_button_group_delete);
+  builder->get_widget("button_group_delete", m_button_group_delete);
   m_button_group_delete->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_button_group_delete) );
 
-  refGlade->get_widget("button_group_users", m_button_group_users);
+  builder->get_widget("button_group_users", m_button_group_users);
   m_button_group_users->signal_clicked().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_button_group_users) );
 
   enable_buttons();
@@ -111,7 +111,7 @@ Dialog_GroupsList::~Dialog_GroupsList()
 }
 
 /*
-void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
+void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
 {
   m_modified = false;
 
@@ -125,7 +125,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
     m_label_table_name->set_text(table_name);
     m_entry_table_title->set_text( document->get_table_title(table_name) );
 
-    Document_Glom::type_list_layout_groups mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name, m_layout_platform);
+    Document::type_list_layout_groups mapGroups = document->get_data_layout_groups_plus_new_fields(layout, m_table_name, m_layout_platform);
 
     //If no information is stored in the document, then start with something:
 
@@ -153,7 +153,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document_Glom*
 
     m_model_groups->clear();
 
-    for(Document_Glom::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
     {
       sharedptr<const LayoutGroup> group = iter->second;
 
@@ -209,7 +209,7 @@ void Dialog_GroupsList::on_button_group_delete()
       if(!group.empty())
       {
         //TODO: Prevent deletion of standard groups
-        Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Delete Group")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
+        Gtk::MessageDialog dialog(Utils::bold_message(_("Delete Group")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL);
         dialog.set_secondary_text(_("Are your sure that you wish to delete this group?"));
         dialog.set_transient_for(*this);
 
@@ -219,7 +219,7 @@ void Dialog_GroupsList::on_button_group_delete()
         if(response == Gtk::RESPONSE_OK)
         {
           Glib::ustring strQuery = "DROP GROUP \"" + group + "\"";
-          const bool test = query_execute(strQuery, this);
+          const bool test = query_execute(strQuery);
           if(!test)
             std::cerr << "Box_DB_Table_Definition::on_adddel_delete(): DROP GROUP failed." << std::endl;
 
@@ -237,11 +237,11 @@ void Dialog_GroupsList::on_button_group_new()
   Dialog_NewGroup* dialog = 0;
   try
   {
-    Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "dialog_new_group");
+    Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "dialog_new_group");
 
     refXml->get_widget_derived("dialog_new_group", dialog);
   }
-  catch(const Gnome::Glade::XmlError& ex)
+  catch(const Gtk::BuilderError& ex)
   {
     std::cerr << ex.what() << std::endl;
   }
@@ -259,7 +259,7 @@ void Dialog_GroupsList::on_button_group_new()
   if(!group_name.empty())
   {
     const Glib::ustring strQuery = "CREATE GROUP \"" + group_name + "\"";
-    const bool test = query_execute(strQuery, this);
+    const bool test = query_execute(strQuery);
     if(!test)
       std::cout << "Dialog_GroupsList::on_button_group_new(): CREATE GROUP failed." << std::endl;
 
@@ -268,9 +268,9 @@ void Dialog_GroupsList::on_button_group_new()
     priv.m_view = true;
     priv.m_edit = true;
 
-    Document_Glom::type_listTableInfo table_list = get_document()->get_tables(true /* plus system prefs */);
+    Document::type_listTableInfo table_list = get_document()->get_tables(true /* plus system prefs */);
 
-    for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
       Privs::set_table_privileges(group_name, (*iter)->get_name(), priv);
     }
@@ -298,11 +298,11 @@ void Dialog_GroupsList::on_button_group_users()
       Dialog_UsersList* dialog = 0;
       try
       {
-        Glib::RefPtr<Gnome::Glade::Xml> refXml = Gnome::Glade::Xml::create(Utils::get_glade_file_path("glom_developer.glade"), "window_users");
+        Glib::RefPtr<Gtk::Builder> refXml = Gtk::Builder::create_from_file(Utils::get_glade_file_path("glom_developer.glade"), "window_users");
 
         refXml->get_widget_derived("window_users", dialog);
       }
-      catch(const Gnome::Glade::XmlError& ex)
+      catch(const Gtk::BuilderError& ex)
       {
         std::cerr << ex.what() << std::endl;
       }
@@ -366,8 +366,8 @@ void Dialog_GroupsList::fill_group_list()
   //Fill the model rows:
   m_model_groups->clear();
 
-  type_vecStrings group_list = Privs::get_database_groups();
-  for(type_vecStrings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+  type_vec_strings group_list = Privs::get_database_groups();
+  for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
   {
     Gtk::TreeModel::iterator iterTree = m_model_groups->append();
     Gtk::TreeModel::Row row = *iterTree;
@@ -398,7 +398,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
   //Fill the model rows:
   m_model_tables->clear();
 
-  Document_Glom* pDocument = get_document();
+  Document* pDocument = get_document();
   if(pDocument)
   {
     // Make sure that these are in the document,
@@ -406,9 +406,9 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
     GroupInfo group_info;
     group_info.set_name(group_name);
 
-    Document_Glom::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
+    Document::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
 
-    for(Document_Glom::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
     {
       Gtk::TreeModel::iterator iterTree = m_model_tables->append();
       Gtk::TreeModel::Row row = *iterTree;
@@ -496,7 +496,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   strQuery += " GROUP \"" + group_name + "\"";
 
-  const bool test = query_execute(strQuery, this); //TODO: Handle errors.
+  const bool test = query_execute(strQuery); //TODO: Handle errors.
   if(!test)
     std::cerr << "Dialog_GroupsList::set_table_privilege(): GRANT/REVOKE failed." << std::endl;
 
