@@ -35,6 +35,11 @@
 #include <glom/mode_design/layout/layout_item_dialogs/dialog_field_layout.h>
 #include <glom/utils_ui.h>
 #include <glom/glade_utils.h>
+
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/button.h>
+#endif //GLOM_ENABLE_MAEMO
+
 #include <glibmm/i18n.h>
 
 namespace Glom
@@ -91,7 +96,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
   {
     //The GNOME HIG says that labels should have ":" at the end:
     //http://library.gnome.org/devel/hig-book/stable/design-text-labels.html.en
-    m_label.set_label(title + ":");
+    m_label.set_label(title + ':');
     m_label.set_alignment(0);
     m_label.show();
 
@@ -164,7 +169,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
         TextViewGlom* textview = Gtk::manage(new TextViewGlom(glom_type));
         pFieldWidget = textview;
       }
-      else
+      else  //TYPE_DATE, TYPE_NUMBER, etc.
       {
         EntryGlom* entry = Gtk::manage(new EntryGlom(glom_type));
         pFieldWidget = entry;
@@ -195,7 +200,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
   if(m_child)
   {
     //Use the text formatting:
-    apply_formatting(*m_child, field->get_formatting_used());
+    apply_formatting(*m_child, field);
     
     bool child_added = false; //Don't use an extra container unless necessary.
 
@@ -225,6 +230,7 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       hbox_parent->set_spacing(Utils::DEFAULT_SPACING_SMALL);
 
       hbox_parent->pack_start(*m_child);
+      hbox_parent->show();
       add(*hbox_parent);
 
       child_added = true;
@@ -233,7 +239,11 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     if(glom_type == Field::TYPE_DATE)
     {
       //Let the user choose a date from a calendar dialog:
-      Gtk::Button* button_date = Gtk::manage(new Gtk::Button(_("..."))); //TODO: A better label/icon for "Choose Date". 
+      #ifndef GLOM_ENABLE_MAEMO
+      Gtk::Button* button_date = Gtk::manage(new Gtk::Button(_("..."))); //TODO: A better label/icon for "Choose Date".
+      #else
+      Gtk::Button* button_date = Gtk::manage(new Hildon::Button(Gtk::Hildon::SIZE_FINGER_HEIGHT, Hildon::BUTTON_ARRANGEMENT_HORIZONTAL, _("..."), ""));
+      #endif
       button_date->set_tooltip_text(_("Choose a date from an on-screen calendar.")); 
       button_date->show();
       hbox_parent->pack_start(*button_date);
@@ -243,7 +253,11 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     if((field_used_in_relationship_to_one || field_is_related_primary_key) && hbox_parent)
     {
       //Add a button for related record navigation:
+      #ifndef GLOM_ENABLE_MAEMO
       m_button_go_to_details = Gtk::manage(new Gtk::Button(Gtk::Stock::OPEN));
+      #else
+      m_button_go_to_details = Gtk::manage(new Hildon::Button(Gtk::Hildon::SIZE_FINGER_HEIGHT, Hildon::BUTTON_ARRANGEMENT_HORIZONTAL, _("Open"), ""));
+      #endif
       m_button_go_to_details->set_tooltip_text(_("Open the record identified by this ID, in the other table."));
       hbox_parent->pack_start(*m_button_go_to_details);
       m_button_go_to_details->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_open_details));
@@ -253,7 +267,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
       //can generally not be edited via another table's layout.
       if(field_used_in_relationship_to_one)
       {
+        #ifndef GLOM_ENABLE_MAEMO
         Gtk::Button* button_select = Gtk::manage(new Gtk::Button(Gtk::Stock::FIND));
+        #else
+        Gtk::Button* button_select = Gtk::manage(new Hildon::Button(Gtk::Hildon::SIZE_FINGER_HEIGHT, 
+           Hildon::BUTTON_ARRANGEMENT_HORIZONTAL, _("Find"), ""));
+        #endif
         button_select->set_tooltip_text(_("Enter search criteria to identify records in the other table, to choose an ID for this field."));
         hbox_parent->pack_start(*button_select);
         button_select->signal_clicked().connect(sigc::mem_fun(*this, &DataWidget::on_button_select_id));
@@ -358,7 +377,7 @@ const Gtk::Label* DataWidget::get_label() const
 void DataWidget::set_child_size_by_field(const sharedptr<const LayoutItem_Field>& field)
 {
   const Field::glom_field_type glom_type = field->get_glom_type();
-  const int width = get_suitable_width(field);
+  int width = get_suitable_width(field);
 
   if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
     m_child->set_size_request(width, width);
@@ -367,12 +386,21 @@ void DataWidget::set_child_size_by_field(const sharedptr<const LayoutItem_Field>
     int height = -1; //auto.
     if((glom_type == Field::TYPE_TEXT) && (field->get_formatting_used().get_text_format_multiline()))
     {
+      #ifndef GLOM_ENABLE_MAEMO 
       int example_width = 0;
       int example_height = 0;
       Glib::RefPtr<Pango::Layout> refLayout = create_pango_layout("example"); //TODO: Use different text, according to the current locale, or allow the user to choose an example?
       refLayout->get_pixel_size(example_width, example_height);
+      
       if(example_height > 0)
         height = example_height * field->get_formatting_used().get_text_format_multiline_height_lines();
+      #else
+      //On Maemo, TextView widgets expand automatically.
+      //TODO: Expansion only happens if both are -1, and vertical expansion never happens.
+      //See bug https://bugs.maemo.org/show_bug.cgi?id=5515
+      width = -1;
+      height = -1; 
+      #endif //GLOM_ENABLE_MAEMO
     }
 
     m_child->set_size_request(width, height);
@@ -418,80 +446,6 @@ void DataWidget::set_editable(bool editable)
   }
 }
 
-/*
-void DataWidget::setup_menu()
-{
-  m_refActionGroup->add(m_refContextLayout,
-    sigc::mem_fun(*this, &DataWidget::on_menupopup_activate_layout) );
-
-  m_refActionGroup->add(m_refContextLayoutProperties,
-    sigc::mem_fun(*this, &DataWidget::on_menupopup_activate_layout_properties) );
-
-  m_refActionGroup->add(m_refContextAddField,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_FIELD ) );
-
-  m_refActionGroup->add(m_refContextAddRelatedRecords,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_PORTAL ) );
-
-  m_refActionGroup->add(m_refContextAddGroup,
-    sigc::bind( sigc::mem_fun(*this, &DataWidget::on_menupopup_add_item), LayoutWidgetBase::TYPE_GROUP ) );
-
-  //TODO: This does not work until this widget is in a container in the window:s
-  App_Glom* pApp = get_application();
-  if(pApp)
-  {
-    pApp->add_developer_action(m_refContextLayout); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextLayoutProperties); //So that it can be disabled when not in developer mode.
-    pApp->add_developer_action(m_refContextAddField);
-    pApp->add_developer_action(m_refContextAddRelatedRecords);
-    pApp->add_developer_action(m_refContextAddGroup);
-
-    pApp->update_userlevel_ui(); //Update our action's sensitivity. 
-  }
-
-  m_refUIManager = Gtk::UIManager::create();
-
-  m_refUIManager->insert_action_group(m_refActionGroup);
-
-  //TODO: add_accel_group(m_refUIManager->get_accel_group());
-
-  try
-  {
-    Glib::ustring ui_info = 
-        "<ui>"
-        "  <popup name='ContextMenu'>"
-        "    <menuitem action='ContextLayout'/>"
-        "    <menuitem action='ContextLayoutProperties'/>"
-        "    <menuitem action='ContextAddField'/>"
-        "    <menuitem action='ContextAddRelatedRecords'/>"
-        "    <menuitem action='ContextAddGroup'/>"
-        "  </popup>"
-        "</ui>";
-
-    m_refUIManager->add_ui_from_string(ui_info);
-  }
-  catch(const Glib::Error& ex)
-  {
-    std::cerr << "building menus failed: " <<  ex.what();
-  }
-
-  //Get the menu:
-  m_pMenuPopup = dynamic_cast<Gtk::Menu*>( m_refUIManager->get_widget("/ContextMenu") ); 
-  if(!m_pMenuPopup)
-    g_warning("menu not found");
-
-
-  if(pApp)
-  {
-    const bool sensitive = pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER;
-    m_refContextLayout->set_sensitive(sensitive);
-    m_refContextAddField->set_sensitive(sensitive);
-    m_refContextAddRelatedRecords->set_sensitive(sensitive);
-    m_refContextAddGroup->set_sensitive(sensitive);
-  }
-}
-*/
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 bool DataWidget::on_button_press_event(GdkEventButton *event)
 {
@@ -569,8 +523,10 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
   if(dialog)
   {
     dialog->set_document(document, table_name, start_field);
-    dialog->set_transient_for(*app);
-    int response = dialog->run();
+    if(app)
+      dialog->set_transient_for(*app);
+
+    const int response = dialog->run();
     dialog->hide();
     if(response == Gtk::RESPONSE_OK)
     {
@@ -599,7 +555,11 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
     {
       add_view(dialog); //Give it access to the document.
       dialog->set_field(start_field, m_table_name);
-      dialog->set_transient_for(*get_application());
+
+      Gtk::Window* parent = get_application();
+      if(parent)
+        dialog->set_transient_for(*parent);
+
       const int response = dialog->run();
       dialog->hide();
       if(response == Gtk::RESPONSE_OK)
@@ -740,7 +700,9 @@ void DataWidget::on_button_choose_date()
 
   if(dialog)
   {
-    dialog->set_transient_for(*get_application());
+    Gtk::Window* parent = get_application(); //This doesn't work (and would be wrong) when the widget is in a Field Definitions dialog.
+    if(parent)
+      dialog->set_transient_for(*parent);
     dialog->set_date_chosen(get_value());
 
     const int response = Glom::Utils::dialog_run_with_help(dialog, "dialog_choose_date");
@@ -798,7 +760,9 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
   if(dialog)
   {
     //dialog->set_document(get_document(), table_name, field);
-    dialog->set_transient_for(*get_application());
+    Gtk::Window* parent = get_application();
+    if(parent)
+      dialog->set_transient_for(*parent);
     add_view(dialog);
 
     //Discover the related table, in the relationship that uses this ID field:
