@@ -21,20 +21,30 @@
 #ifndef GLOM_UTILITY_WIDGETS_ENTRY_GLOM_H
 #define GLOM_UTILITY_WIDGETS_ENTRY_GLOM_H
 
-#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
+#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
 
 #include <gtkmm.h>
 #include <libglom/data_structure/field.h>
 #include "layoutwidgetfield.h"
 #include <gtkmm/builder.h>
 
+#ifdef GLOM_ENABLE_MAEMO
+#include <hildonmm/entry.h>
+#endif
+
 namespace Glom
 {
 
 class App_Glom;
 
+
 class EntryGlom
-: public Gtk::Entry,
+:
+#ifdef GLOM_ENABLE_MAEMO
+  public Hildon::Entry,
+#else
+  public Gtk::Entry,
+#endif
   public LayoutWidgetField
 {
 public:
@@ -42,6 +52,8 @@ public:
   explicit EntryGlom(Field::glom_field_type glom_type = Field::TYPE_TEXT);
   virtual ~EntryGlom();
 
+  virtual void set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name);
+
   void set_glom_type(Field::glom_field_type glom_type);
 
   //Override this so we can store the text to compare later.
@@ -65,7 +77,6 @@ private:
   virtual void on_changed(); //From Gtk::Entry.
   virtual void on_activate(); //From Gtk::Entry.
   virtual bool on_focus_out_event(GdkEventFocus* event); //From Gtk::Widget
-  virtual void on_insert_text(const Glib::ustring& text, int* position); //From Gtk::Editable
 
   virtual void check_for_change();
 
