@@ -435,7 +435,9 @@ void ImageGlom::on_menupopup_activate_select_file()
         std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog);
 
         App_Glom* pApp = get_application();
-        dialog->set_transient_for(*pApp);
+        if(pApp)
+          dialog->set_transient_for(*pApp);
+
         dialog->load(uri);
 
         if(dialog->run() == Gtk::RESPONSE_ACCEPT)
@@ -600,7 +602,7 @@ void ImageGlom::setup_menu_usermode()
   catch(const Glib::Error& ex)
   {
 #else
-  if(error.get() != NULL)
+  if(error.get())
   {
     const Glib::Error& ex = *error.get();
 #endif
